Function get_stripe_resid, im,par

;This function is used to smooth an average CCD image
;Inputs: im - the image  with m columns, n lines
;		 par - a 2 element array, containing the size of the gausian boxcar and its 1sigma width
;Returns a "junk image"
;History - Mario and Trevor forever
;22 Sep 2008    Adjusted spectral gaussian so that 0 is a valid value(acts as a delta function) and corrects
;               band shifting for high precision usage



;0) Get sizes of im (define m,n)
s=size(im)
m=s(1)
n=s(2)

im=alog(im)
;stop


;2) Now, we apply a gaussian filter of s x s pixels (par(0)) and stdev=sigma (par(1)) to lNuxBeta

;a) extract values from par:
x=par(0)    ;size of kernel in x direction
l=par(0)    ;size of kernel in l direction, currently a square of dimensions (x by x) is used instead
sigmaX=par(1)
sigmaL=par(2)

;b)generate the gaussian box (kernel) of the appropriate dimensions
;kernel=shift(dist(s),s/2.,s/2.)
;kernel=exp(-(kernel/sigma)^2)

if(sigmaL eq 0) then begin
  l=1
endif

kernel = fltarr(x,l)
kernel[*,*] = 1.
centerX = x/2.
centerL = l/2.
if(sigmaL eq 0) then begin
  kernel[*,*] = 0
  kernel[*,centerL] = 1
endif else begin
  for i=0, l-1 do begin
    kernel[*,i]=kernel[*,i] *  exp(-1*(i-centerL)^2/(2*sigmaL^2))
  endfor
endelse
  
for i=0, x-1 do begin
  kernel[i,*]=kernel[i,*] *  exp(-1*(i-centerX)^2/(2*sigmaX^2))
endfor




;kernel=kernel/total(kernel) ;this is replaced by the /normalize keyword in convol

;c) convolve gaussian kernel with lNuxBeta
lGammaHat=convol(im,kernel,/center,/edge_truncate,/nan,/normalize)


;3) Subtract the filtered image from the lNuxBeta to generate a residual image
nu=exp(im-lGammaHat)


return, nu 

end
