;02/06/2009 (fps)
;   Initial development - ENVI interface for mro_crism_continuum_cube()
;   	Query EVNI ABL for input cube
;   	ENVI BIL tiling
;   	Output to memory or file
;02/06/2009 (fps) - Changes since sending code to RVM @ ~4:45 ET
;   Properly handle selection of cancel button on interface widget
;   Open output file in ABL with separate call to envi_open_file, as opposed to using /open option in envi_setup_head
;   	For some strange reason the latter causes z-plot issues with the resulting cube... still have issues with in-memory cubes...
;03/10/2009 (fps)
;   Added optional 'event' argument for ENVI menu support
;12/02/2009 (mfm)
;   Use get_cat_header_data and write_cat_header. Make full header when writing to file. 
;12/04/2009 (mfm)
;	Check min(def_bands) instead of total(def_bands) 
;11/17/2010 (mfm)
;	add header parameter CAT_PRODUCT_VERSION
;11/18/2010 (mfm)
;	four more CAT header parameters
;11/05/2010 (fps)
;   Fixed specification of default bands to load and band names for parameter output cube
;12/20/2010 (mfm)
;   Resolved svn conflict with last updates (mfm vs fps) - no real problem
;11/14/2011 (fps)
;   Removed CAT-dependencies from mro_crism_continuum_cube_envi
;   CAT integration supported by mro_crism_continuum_cat_cube_envi
;

pro mro_crism_continuum_cube_envi, event

procedure_name = 'MRO CRISM CONTINUUM CUBE'

;Set compiler options
compile_opt strictarr

;;Simple catch to prevent crash
;catch, error
;;error = 0
;if (error NE 0) then begin
;	;Convert !error_state structure to a string array
;	help, !error_state, /struct, output = error_state_report
;	help, !error_state, /struct
;
;	error_dialog = dialog_message(error_state_report, /error, title = procedure_name +': Unexpected Error')
;
;	if (strupcase(error_dialog) EQ 'OK') then return
;endif

;Select input band from available bands list
envi_select, fid=in_fid, pos=in_pos, dims=in_dims, file_type=in_file_type, $
         /file_only, /no_spec, /no_dims, title = procedure_name + ': Select Input Cube'
if (in_fid[0] eq -1) then begin
    print, procedure_name + ': Cancel/Invalid FID'
    return
endif

;Gather some useful info
envi_file_query, in_fid, fname = in_filename, ns=ns, nl=nl, nb=nb, $
    	    	 wl=wl, bnames=bnames, bbl=bbl, def_bands = def_bands, data_ignore_value = data_ignore_value, interleave = interleave


;Overmand in_pos which reflects bbl by default...
in_pos = lindgen(nb)


;print, in_fid
;print, in_filename
;print, ns,nl,nb
;help, in_pos
;help, wl
;help, bnames
;help, bbl
;print, data_ignore_value
;help, map_info_struct, /struct


data_ignore_default = 1.0E-34
ignore_val = 65535.0

if (data_ignore_value EQ data_ignore_default) then begin
    data_ignore_value = ignore_val
endif

;wavelength_struct = mro_crism_wavelength_defaults(wl)
;continuum_info_struct = mro_crism_continuum_cube_envi_gui(in_filename, nb, wavelength_vec = wl, default_indx = [wavelength_struct.rgb_indx[2], wavelength_struct.rgb_indx[0]])

if (n_elements(def_bands) NE 3) then begin
    def_bands = reverse((lindgen(3) + 1) * (nb/4))
endif
continuum_info_struct = mro_crism_continuum_cube_envi_gui(in_filename, nb, wavelength_vec = wl, default_indx = [def_bands[2], def_bands[0]])


;stop

if (continuum_info_struct.cancel EQ 1) then begin
    print, procedure_name + ': Cancel'
    return
endif

print, continuum_info_struct
help, continuum_info_struct, /struct

result_select = continuum_info_struct.result_select
param_indx = continuum_info_struct.param_indx
param_text = continuum_info_struct.param_text
median_select = continuum_info_struct.median_select
median_window = long(continuum_info_struct.median_text)

if ((median_select EQ 0) OR (median_window EQ 1)) then begin
    cont_median_window = 0
endif else begin
    cont_median_window = median_window
endelse

if (continuum_info_struct.ref_select EQ 0) then begin
    cont_lambda_vec = wl
    cont_tie_lambda = float(param_text)
    cont_tie_indx = 0
endif else begin
    cont_lambda_vec = 0
    cont_tie_lambda = 0
    cont_tie_indx = long(param_indx)
endelse

if (total(continuum_info_struct.tie_band_select_vec) GT 0) then begin
    tie_band_indx = where(continuum_info_struct.tie_band_select_vec NE 0, num_tie_band_indx)

    for i = 0, num_tie_band_indx -1 do begin

    
    endfor
    
endif



;stop

;Set parameters
result_dims = in_dims
result_dt = 4 ;floating point
result_nb_array = [nb,nb,2]

out_status_string_array = ['Continuum: [Inactive]', $
    	    	    	   'Ratio: [Inactive]',     $
			   'Parameter: [Inactive]']

out_ptr_array = ptrarr(3, /allocate_heap)
print, ptr_valid(out_ptr_array)

active_indx = where(result_select EQ 1, num_active_indx)
for i = 0, num_active_indx -1 do begin
    print, active_indx[i]

    ;memory check...
    mem_check = magic_mem_check(dims=result_dims, in_memory = continuum_info_struct.outfm_result_array[active_indx[i]].in_memory, out_dt=result_dt, nb=result_nb_array[active_indx[i]], $
    	    	    	    	out_name = continuum_info_struct.outfm_result_array[active_indx[i]].name)

    if (mem_check.cancel EQ 1) then begin
	print, procedure_name + ': Cancel'
	for j = 0, n_elements(out_ptr_array) -1 do begin
    	    ptr_free, out_ptr_array[j]
	endfor
	
	return
	
    endif

    ;Store result of memory check in info structure
    continuum_info_struct.outfm_result_array[active_indx[i]].in_memory = mem_check.in_memory
    continuum_info_struct.outfm_result_array[active_indx[i]].name = mem_check.out_name

    ;Declare in-memory output array or open output file
    if (continuum_info_struct.outfm_result_array[active_indx[i]].in_memory EQ 1) then begin
	*out_ptr_array[active_indx[i]] = make_array(ns, nl, result_nb_array[active_indx[i]], value = !values.f_nan, /float)
	out_status_string_array[active_indx[i]] = (strsplit(out_status_string_array[active_indx[i]], ' ', /extract))[0] + ' ' + '[In Memory]'
    endif else begin
	openw, result_lun, continuum_info_struct.outfm_result_array[active_indx[i]].name, /get_lun
	out_status_string_array[active_indx[i]] = (strsplit(out_status_string_array[active_indx[i]], ' ', /extract))[0] + ' ' + continuum_info_struct.outfm_result_array[active_indx[i]].name
	*out_ptr_array[active_indx[i]] = result_lun
    endelse
    
endfor

print, transpose(out_status_string_array)

;stop

;Initiate BIL tiling
in_tile_id = envi_init_tile(in_fid, in_pos, num_tiles = num_in_tiles, interleave = 1, $     	    ;BIL tiling
    	    	    	    xs = in_dims[1], xe = in_dims[2], ys = in_dims[3], ye = in_dims[4])

envi_report_init, out_status_string_array, base = status_base, title = procedure_name, /interupt

envi_report_inc, status_base, num_in_tiles

;Main processing loop - one iteration for each tile
for i = long(0), num_in_tiles -1 do begin

    envi_report_stat, status_base, i, num_in_tiles, cancel=cancel
    
    if (cancel) then begin
	print, procedure_name + ': Cancel'
	envi_report_init, base = status_base, /finish
	
	file_indx = where((continuum_info_struct.outfm_result_array.in_memory EQ 0) AND (result_select EQ 1), num_file_indx)
	if (num_file_indx GT 0) then begin
	    for j = 0, num_file_indx -1 do begin
		free_lun, *out_ptr_array[file_indx[j]]
	    endfor
	endif

	for j = 0, n_elements(out_ptr_array) -1 do begin
	    ptr_free, out_ptr_array[j]
	endfor
	
	return
	
    endif

    ;Grab tile data
    in_data = envi_get_tile(in_tile_id, i)

    in_data = reform(in_data, n_elements(in_data[*,0]), 1, n_elements(in_data[0,*]))




    ;stop
    
    continuum_struct = mro_crism_continuum_cube(in_data, lambda_vec = cont_lambda_vec, tie_lambda = cont_tie_lambda, tie_indx = cont_tie_indx, $
    	    	    	    	    	    	continuum_cube = result_select[0], ratio_cube = result_select[1], parameter_cube = result_select[2], $
					    	median_window = cont_median_window)

    for j = 0, n_elements(result_select) -1 do begin
	if (result_select[j] EQ 1) then begin
	    if (n_elements(*out_ptr_array[j]) EQ 1) then begin
		;file lun - write result to file
		writeu, *out_ptr_array[j], continuum_struct.(j)
	    endif else begin
		;in memory cube - store result
		(*out_ptr_array[j])[*,i,*] = continuum_struct.(j)
	    endelse
	endif
    endfor

endfor

envi_tile_done, in_tile_id

envi_report_init, base = status_base, /finish


if ((n_elements(def_bands) eq 3) && (min(def_bands) gt 0)) then begin
	def_bands -= 1
endif else begin
	def_bands = [0,0,0]
endelse

;Register memory item in ENVI session or close output file and write ENVI header
for j = 0, n_elements(result_select) -1 do begin

    ;if parameter cube is requested, set default band(s) to load to one, band names to parameter names
    if (j EQ 2) then begin
    	def_bands = [1]
    	bnames = ['P0', 'P1']
    endif

    if (result_select[j] EQ 1) then begin
    	if (n_elements(*out_ptr_array[j]) EQ 1) then begin
    	    ;file lun - close file and write header
    	    free_lun, *out_ptr_array[j]
    	    envi_setup_head, fname = continuum_info_struct.outfm_result_array[j].name, ns = ns, nl = nl, nb = result_nb_array[j], $
    	    	    	     interleave = 1, data_type = 4, offset = 0, data_ignore_value = data_ignore_value, $
    	    	    	     wl = wl, bnames = bnames, def_bands=def_bands, bbl = bbl, map_info = map_info_struct, $
    	    	    	     /write;, /open

    	    envi_open_file, continuum_info_struct.outfm_result_array[j].name, /no_interactive_query, r_fid = fid
	    if (fid EQ -1) then begin
	    	print, 'Abandon hope all ye who enter here...'
		stop
	    endif

    	endif else begin
    	    ;in memory cube - register with ENVI 
    	    envi_enter_data, (*out_ptr_array[j]), data_ignore_value = data_ignore_value, $
    	    	    	      wl = wl, bnames = bnames, def_bands=def_bands, bbl = bbl, map_info = map_info_struct
	    
    	endelse

    endif
    ;destroy pointers
    ptr_free, out_ptr_array[j]
endfor

END
