;+
; NAME:
;
;
; PURPOSE:
;
;
; AUTHOR:
;
;
; CATEGORY:
;
;
; CALLING SEQUENCE:
;
;
; OPTIONAL INPUTS:
;
;
; KEYWORDS:
;
;
; OUTPUTS:
;
; COMMON BLOCKS:
;
;
; DEPENDENCIES:
;
; PROCEDURE:
;
;
; EXAMPLE:
;
;
; RESTRICTIONS:
;
; MODIFICATION HISTORY:
; ~Sep 15, 2006: Frank Seelos
; --Initial development
; Nov 02,2006: Shannon Pelkey
; --Added traceability to input file by adding descriptor to ENVI hdr.
; March 10, 2009: Frank Seelos
; --Minimal code cleanup for CAT 6.5 release
; --Force wl vector to be floating point - was being treated as a string array and causing problems in the ENVI header
;;
;-
;###########################################################################
;
; LICENSE
;
;###########################################################################

pro mro_crism_spectral_stats_envi, event

procedure_title = 'MRO CRISM SPECTRAL STATS'

;Set compiler options
compile_opt strictarr

;Simple catch to prevent crash
catch, error
if (error NE 0) then begin
    ;Convert !error_state structure to a string array
    help, !error_state, /struct, output = error_state_report
    help, !error_state, /struct

    error_dialog = dialog_message(error_state_report, /error, title = procedure_title + ': Unexpected Error')

    if (strupcase(error_dialog) EQ 'OK') then return
endif

;Select input band from available bands list
envi_select, fid=in_fid, pos=in_pos, dims=in_dims, file_type=in_file_type, title = procedure_title + ': Select Input File', $
			 /mask, m_fid = mask_fid

if (in_fid[0] eq -1) then begin
    print, procedure_title + ': Cancel/Invalid FID'
    return
endif

;Gather some useful info
envi_file_query, in_fid, fname = in_filename, ns=in_ns, nl=in_nl, nb=in_nb, wl=in_wl

in_wl = float(in_wl)

if (mask_fid[0] NE -1) then begin
;   print, 'MASK!'
;   print, mask_fid

    ;Gather some useful info about the mask
    envi_file_query, mask_fid, fname = mask_filename, ns=mask_ns, nl=mask_nl, nb=mask_nb, dims=mask_dims

    ;Grab mask band
    mask_data = envi_get_data(fid = mask_fid, pos = 0, dims=mask_dims)

endif else begin
;   print, 'NO MASK!'
;   print, mask_fid
    mask_data = 0
endelse


;Check for referencing info
in_map_info = envi_get_map_info(fid = in_fid)
in_projection_info = envi_get_projection(fid = in_fid)

;Construct default output filenames
last_slash = strpos(in_filename, '/', /reverse_search) > strpos(in_filename, '\', /reverse_search)
last_dot = strpos(in_filename, '.', /reverse_search)

in_file_directory = strmid(in_filename, 0, last_slash + 1)
in_file_basename = strmid(in_filename, last_slash + 1, last_dot - last_slash -1)
if (last_dot NE -1) then begin
	in_file_extension = strmid(in_filename, last_dot)
endif else begin
	in_file_extension = ''
endelse

output_file = in_file_directory + in_file_basename + '_SPECSTATS.sli'

;Gather user input info via ENVI auto managed widgets
auto_base = widget_auto_base(title = procedure_title)
main_base = widget_base(auto_base, /column)
    specstats_list = ['Maximum', 'Mean + Stddev', 'Mean', 'Median', 'Mean - Stddev', 'Minimum']
    specstats_select = widget_multi(main_base, /auto_manage, list = specstats_list, uvalue = 'specstats_select', /no_range, $
								     default = replicate(1b, n_elements(specstats_list)), ysize = 150)
    specstats_outfm = widget_outfm(main_base, /auto_manage, /frame, default = output_file, uvalue = 'specstats_outfm')

result = auto_wid_mng(auto_base)

if (result.accept EQ 0) then begin
    print, procedure_title + ': Cancel'
    return
endif

;help, result, /struct
;print, result

in_samples = in_dims[2] - in_dims[1] + 1
in_lines = in_dims[4] - in_dims[3] + 1

;Set output parameters
out_dims = [-1, 0, n_elements(in_pos) -1, 0, total(result.specstats_select) -1]
out_dt = 4 ;floating point
out_pos = 0
out_nb = n_elements(out_pos)
out_ns = n_elements(in_pos)
out_nl = total(result.specstats_select)


;memory check
mem_check = magic_mem_check(dims=in_dims, in_memory = result.specstats_outfm.in_memory, $
    	    out_dt=out_dt, nb=out_nb, out_name = result.specstats_outfm.name)

if (mem_check.cancel EQ 1) then begin
    print, procedure_title + ': Cancel'
    return
endif

;Store result of memory check in result structure
result.specstats_outfm.in_memory = mem_check.in_memory
result.specstats_outfm.name = mem_check.out_name


;Requies sequental processing of spatially complete spectral bands
;"Pseudo-Tiling"

;Decalare output spectral channel column
output_column = make_array(total(result.specstats_select), value = 0.0, /float)

;Declare in-memory output array or open output file
if (result.specstats_outfm.in_memory EQ 1) then begin
    output_array = make_array(n_elements(in_pos), total(result.specstats_select), out_nb, value = 0.0, /float)
    out_status_string = 'Output to Memory'
endif else begin
    ;This is a funny case where the calc interleave is effectively BIC.
    ;Store result in memory and write to file at the end...
    output_array = make_array(n_elements(in_pos), total(result.specstats_select), out_nb, value = 0.0, /float)
    out_status_string = 'Output File: ' + result.specstats_outfm.name
endelse


;Wrangle widget return info
mean_select = result.specstats_select[2]
median_select = result.specstats_select[3]
min_select = result.specstats_select[5]
max_select = result.specstats_select[0]
stddev_plus_select = result.specstats_select[1]
stddev_minus_select = result.specstats_select[4]

;print, mean_select
;print, median_select
;print, min_select
;print, max_select
;print, stddev_plus_select
;print, stddev_minus_select

;Assemble string to be displayed in ENVI status window
status_string_array = ['Input File: ' + in_filename, $
					   out_status_string]

envi_report_init, status_string_array, base = status_base, title = procedure_title, /interupt

envi_report_inc, status_base, n_elements(in_pos)


;Initialize pseudo tiling
;Main processing loop - one iteration for each band
for k = 0, n_elements(in_pos) -1 do begin

    envi_report_stat, status_base, k, n_elements(in_pos), cancel=cancel

    if (cancel) then begin
    	print, procedure_title + ': Cancel'
    	envi_report_init, base = status_base, /finish

    	if (result.specstats_outfm.in_memory EQ 0) then begin
    	    free_lun, out_lun
    	endif

    	return
    endif

    ;Grab spectral band
    in_data = envi_get_data(fid = in_fid, pos = in_pos[k], dims=in_dims)
    ;print, k
    ;help, in_data

    output_column = mro_crism_spectral_stats(in_data, mask = mask_data, mean_select=mean_select, median_select=median_select, $
    	    	    stddev_plus_select=stddev_plus_select, stddev_minus_select=stddev_minus_select, $
    	    	    min_select=min_select, max_select=max_select)

    ;help, output_column

    ;Store in output array
    output_array[k,*] = output_column

endfor

envi_report_init, base = status_base, /finish


;Register memory item in ENVI session or write file and generate header for output file
if (result.specstats_outfm.in_memory EQ 1) then begin
    envi_enter_data, output_array, wl = in_wl[in_pos], spec_names = specstats_list[where(result.specstats_select EQ 1)], $
    	    	     file_type = 4, bnames = procedure_title
endif else begin
    openw, out_lun, result.specstats_outfm.name, /get_lun
    	writeu, out_lun, output_array
    free_lun, out_lun

    envi_setup_head, fname = result.specstats_outfm.name, ns = out_ns, nl = out_nl, nb = 1, $
    	    	     file_type = 4, data_type = 4, interleave = 0, offset = 0,$
    	    	     wl = in_wl[in_pos], spec_names = specstats_list[where(result.specstats_select EQ 1)], $
    	    	     descrip='CRISM Spectral Stats from '+in_file_basename+in_file_extension,$
    	    	     bnames = procedure_title, $
    	    	     /write, /open
endelse


END

