pro cat_image_move_event, dn, xloc, yloc, xstart=xstart, ystart=ystart

;-----------------------------------------------------------------------------
; This routine can be configured to trap when the zoom window position 
; is moved within the image window in a display group (ENVI Classic only!)
;
; At present, CAT only uses this to update custom CRISM z-profile plots
; if one is present for the display group where the motion happens. 
; Other actions could be added in future.
;
; To make this routine active in this way, either:
;    1. In envi.cfg, change:
;            user defined move routine   = 
;      to:
;            user defined move routine   = cat_image_move_event
; or 2. In file/preferences enter cat_image_move_event in the 
;       "User Defined Move Routine" box.
;-----------------------------------------------------------------------------


; This common block contains zprofile list created by crism_active_zprofile_event...
common cat_zprofile_com, cat_zprofiles


envi_disp_query, dn, fid=fid
if (fid[0] eq -1) then return

; Get observation nfo needed
;stat = get_cat_header_data(fid, FNAME=datafile)
envi_file_query,fid, FNAME=datafile


; Is there a z-profile already active for this display?
this_zp_idx = -1
nzp = n_elements(cat_zprofiles)
if (nzp gt 0) then begin
	for ii=0,nzp-1 do begin
		widget_control, cat_zprofiles[ii].draw_id, bad_id=inval  ; inval=0 if widget is now deleted
		if (inval eq 0) then begin
			if (cat_zprofiles[ii].datafile eq strupcase(file_basename(datafile))) then begin
				if (cat_zprofiles[ii].dn eq dn) then begin
					if (obj_valid(cat_zprofiles[ii].window)) then begin
						this_zp_idx = ii
						break
					endif
				endif
			endif
		endif
	endfor
endif

if (this_zp_idx ge 0) then crism_active_zprofile_event, ev, display_num=dn


return
end
