; ENVI event handler routine to calculate CRISM IR wavelength shift 
; for an open image from WC CDRs.
;
; Calls: get_cat_header_data
;        get_wc_coeff
;        crism_wavelength_shift
;
; Created 2009 Mar 12 by Frank Morgan
; Sep 17,2009 MFM: --find_lblfile returns '' not '-1' on fail
; Sep 30,2009 MFM: --use get_wc_coeff 
; Nov 24,2010 MFM: --Use get_cat_header_data to get inputs 


pro crism_waveshift_event, ev

widget_control, ev.id, get_uvalue=uvalue

; Define ENVI functions used so able to create a sav file:
FORWARD_FUNCTION envi_select, envi_file_query

; Simple catch to prevent crash:
catch, error
if (error NE 0) then begin
	cat_error_report, routine_name='crism_waveshift_event'
	return
endif


;=======================================
;    PICK FILE
;=======================================

; Have user pick an open data file to work with:
envi_select,fid=in_fid,/file_only,/no_dims,/no_spec,title='Select file:'
if (in_fid[0] eq -1) then return                  ;cancel selected


;============================================
;    Get wavelength shift inputs
;============================================

; Get SCLK (for WC selection) and optical bench temperature
stat = get_cat_header_data(in_fid, fname=datafile, $
	CAT_SCLK_START          = sclk, $
	CAT_CRISM_BENCH_TEMP    = cat_crism_bench_temp)
obt = float(cat_crism_bench_temp)

if ((stat eq 0) and (strlen(strtrim(sclk)) gt 0) and (obt ne 65535.0)) then begin
	; Get the WC coefficients
	wc = get_wc_coeff(sclk)
	if (max(wc) gt 65534.0) then begin
		msg = 'Invalid WC coefficients retrieved for SCLK ' + strtrim(sclk,2)
		ok = dialog_message(msg, title='CRISM wavelength shift fail')
		return
	endif

	; Compute shift:
	dw = crism_wavelength_shift(wc, obt)
	msg = string(dw,format='(F0.2)') + ' nm wavelength shift for ' $
		+ strtrim(file_basename(datafile),2) $
		+ string([10b]) + '(Estimated from optical bench temperature.)
	ok = dialog_message(msg, title='CRISM wavelength shift')
endif else begin
	msg = 'Could not find header data for '+ strtrim(file_basename(datafile),2)
	ok = dialog_message(msg, title='CRISM wavelength shift fail')
endelse 

return
end
