pro zprofile_axis_event, ev

; Set axis scaling parameters for CAT custom z-profile plots

common cat_zprofile_com, cat_zprofiles

print,'AXIS EVENT'
; Get display number; find the zprofile in the list
widget_control, ev.top, get_uvalue=dn 
envi_disp_query, dn, fid=fid
if (fid[0] eq -1) then begin
	msg = 'Need an open display before setting z-profile axes.'
	ok = dialog_message(msg, title='CRISM Z-Profile Axes', /cancel)
    return
endif
envi_file_query,fid, FNAME=datafile

 
; Is there a z-profile already active for this display?
this_zp_idx = -1
nzp = n_elements(cat_zprofiles)
if (nzp gt 0) then begin
	for ii=0,nzp-1 do begin
		widget_control, cat_zprofiles[ii].draw_id, bad_id=inval  ; inval=0 if widget is OK
		if (inval eq 0) then begin
			if (cat_zprofiles[ii].datafile eq strupcase(file_basename(datafile))) then begin
				if (cat_zprofiles[ii].dn eq dn) then begin
					if (obj_valid(cat_zprofiles[ii].window)) then begin
						this_zp_idx = ii
						break
					endif
				endif
			endif
		endif
	endfor
endif

if (this_zp_idx lt 0) then begin
	msg = 'Open a z-profile for the selected display before setting axes.'
	ok = dialog_message(msg, title='CRISM Z-Profile Axes',/cancel)
    return
endif

; Description for form widgets; defaults for x from current plot,
; defaults for y from current axes setting
cplot = cat_zprofiles[this_zp_idx].plot_obj
xlo = strtrim(string((cplot.xrange)[0], format='(F20.3)'), 2)
xhi = strtrim(string((cplot.xrange)[1], format='(F20.3)'), 2)
caxes = cat_zprofiles[this_zp_idx].axes
ylo = strtrim(string(caxes.ymin, format='(F20.3)'), 2)
yhi = strtrim(string(caxes.ymax, format='(F20.3)'), 2)
fdesc  = [ '0, LABEL, Axis Settings, CENTER', $
           '1, BASE, , ROW, FRAME', $
           '0, FLOAT, ' + xlo + ', label_top=X min, tag=xmin', $
           '2, FLOAT, ' + xhi + ', label_top=X max, tag=xmax', $
            '1, BASE, , ROW, FRAME', $
           '0, FLOAT, ' + ylo + ', label_top=Y min, tag=ymin,', $
           '0, FLOAT, ' + yhi + ', label_top=Y max, tag=ymax', $
           '2, DROPLIST, Auto|Absolute, SET_VALUE='+strtrim(caxes.yscl,2)+', LABEL_TOP=Y Scaling, tag=yscl', $
           '1,  BASE, , ROW', $
           '0, BUTTON,  OK, QUIT, tag=ok', $
           '2, BUTTON,  Cancel, QUIT, tag=cancel' ]

; Create axis set widgets
wForm = cw_form(fdesc, /column, title='Z-profile Axis Scaling')

if (wForm.ok) then begin	
	cat_zprofiles[this_zp_idx].axes.xmin = wForm.xmin
	cat_zprofiles[this_zp_idx].axes.xmax = wForm.xmax
	cat_zprofiles[this_zp_idx].axes.ymin = wForm.ymin
	cat_zprofiles[this_zp_idx].axes.ymax = wForm.ymax
	cat_zprofiles[this_zp_idx].axes.yscl = wForm.yscl
	cat_scale_zprofile, cplot, caxes, cat_zprofiles[this_zp_idx].last_wave, $
	  cat_zprofiles[this_zp_idx].last_y
endif

; note: yscl=0 -> auto; yscl=1 -> absolute
	
end
