;******************************************************************************
;
; function cat_append_history, current_hist, new_hist
;
; Add a new CAT history code to a possibly pre-existing history string.
;
; INPUT:
;	current_hist     string     Existing history string (may be undefined)
;	new_hist         string     New history code to append
;
; OUTPUT PARAMETERS: none
;
; RETURN VALUE:
;	New history string.
;
; NOTES:
;
; HISTORY:
;	2009 Nov 19   Frank Morgan: First version
;
;******************************************************************************

function cat_append_history, current_hist, new_hist


; If current history null, set to '', use new variable to 
; avoid alteration of calling routine data:
if (n_elements(current_hist) eq 0) then begin
	cur_hist = ''
endif else begin
	cur_hist = strtrim(current_hist,2)
	if (cur_hist eq '-1') then cur_hist=''
endelse

; If there's nothing to add, return current:
if (n_elements(new_hist) eq 0) then return,cur_hist
nwh = strtrim(new_hist,2)
if (nwh eq '') then return,cur_hist

; If current history blank, just return the new code:
if (cur_hist eq '') then return,nwh

; If get here, then neither current_hist nor new_hist are blank, 
; join with _ and return:
return, cur_hist + '_' + nwh
end
