;******************************************************************************
;
; pro cat_error_report
;
; Print a full report from !error_state after CAT error trapped.
;
; INPUT: 
;	!error_state	(system variable)
;	(no passed parameters)
;
; OUTPUT: None.
;
; KEYWORDS: 
;	routine_name	string	[optional]	Name of routine where error occured.
;	cat_msg			string	[optional]	Message from CAT.
;	noidlmsg		bool	[optional]	If set, does NOT report IDL !error_state
;
; SIDE EFFECTS:
;	Prints message to dialog box.
;
; HISTORY:
;	2007 Aug 103 F. Morgan: First version complete.
;	2009 Apr 29 F.Morgan  New traceback (D. Fanning) gets calling routine 
;	               position at error, instead of at catch statement
;
;******************************************************************************

pro cat_error_report, routine_name=routine_name, cat_msg=cat_msg, noidlmsg=noidlmsg

NEWLINE = string([10b])

ttl = 'CAT ERROR'
if (size(routine_name,/type) eq 7) then ttl += ': '+strtrim(routine_name,2)

if (n_elements(cat_msg) gt 0) then begin
	msg = cat_msg + NEWLINE
endif else begin
	msg = ''
endelse

; Add traceback info (new version 4/30/09 reports position at error, not at catch statement)
help, /Last_Message, Output=traceback    ; from D. Fanning
if (n_elements(routine_name) gt 0) then begin
	msg += 'Traceback Report from ' + StrUpCase(routine_name) + ':'
endif
for i=0,n_elements(traceback)-1 do msg += NEWLINE + traceback[i]

if (~keyword_set(noidlmsg)) then begin
	; add IDL messages
	msg += 'IDL message:  ' + !error_state.msg + NEWLINE  $
		+ 'NAME:         ' + !error_state.name + NEWLINE $
		+ 'BLOCK:        ' + !error_state.block + NEWLINE $
		+ 'CODE:         ' + strtrim(!error_state.code,2)

	if (strlen(strtrim(!error_state.sys_code_type)) gt 0) then begin
		msg += NEWLINE $
			+ 'SYS_MSG:      ' + !error_state.sys_msg + NEWLINE $
			+ 'SYS_CODE:     ' + strtrim(!error_state.sys_code,2) + NEWLINE $
			+ 'SYS_CODE_TYPE:' + !error_state.sys_code_type
	endif
endif


; 4/30/09 this reported position in calling program at catch statement, not at error
;help,/traceback,output=tb
;for i=0,n_elements(tb)-1 do msg += NEWLINE + tb[i]

error_dialog = dialog_message(msg, /error, title=ttl)
if (strupcase(error_dialog) eq 'OK') then return
end
