;******************************************************************************
;
; function cat_id_at_vs, at_file
;
; Dig a source volcano scan observation ID out of a AT CDR label file.
;
; INPUT PARAMETERS:
;	at_file    string     AT CDR filename
;
; OUTPUT PARAMETERS: None
;
; RETURN VALUE: int status...
;	 string = volcano scan ID   ('' if unable to find one)
;
; KEYWORDS: 
;	BATCH     If set, suppress interactive dialog in downstream functions
;
; NOTES:
;
; TYPICAL CALL:
;
; USES:
;
; HISTORY:
;	2009 Nov 11 F. Morgan: First version written.
;
;******************************************************************************

function cat_id_at_vs, at_file, batch=batch

find_lblfile, at_file, atlbl
if (atlbl eq '') then return,''
if (~file_test(atlbl)) then return,''

; Text preceding volcano scan ID in label notes:
trigger_string = 'derived from volcano scan observation ID'

openr,u, atlbl, /get_lun
s = ''
idstring = ''
while(~eof(u)) do begin
	readf,u, s
	p = strpos(s, trigger_string)
	if (p gt 0) then begin
		idstring = strtrim(strmid(s,p+strlen(trigger_string)),2)
		; Drop '*/' if present:
		p = strpos(idstring,'*')
		if (p ge 0) then idstring = strtrim(strmid(idstring,0,p),2)
		; Drop '.' if present:
		p = strpos(idstring,'.')
		if (p ge 0) then idstring = strtrim(strmid(idstring,0,p),2)
		break
	endif
endwhile
free_lun,u

return, idstring
end
