;******************************************************************************
;
; function cdrspec_for_tile, cdr_row, cdr_spec, tile_row, cdr4tile
;
; Pull relevant bands from a CDR spectrum and reorder to match the bands in a 
; tile spectrum. 
;
; INPUT:
;	cdr_row     intarr(ncdr)    Row index vector from a CDR
;	cdr_spec    fltarr(ncdr)    CDR data values
;	tile_row    intarr(ntile)   Row index vector from the tile MRRWV file, for the 
;	                            bands corresponding to the same channel (IR or VNIR) 
;	                            as the CDR.
;
; OUTPUT:
;	cdr4tile   fltarr(ntile)    CDR data at the tile bands, reordered to match.
;
; KEYWORDS: None
;
; RETURN VALUE:  status code...
;	 0: success
;	-1: no overlap at all between CDR and tile rows.
;
; NOTES:
;
; USES:
;
; HISTORY:
;	2009 Jan 11  F.Morgan  First version.  Tested.
;
;******************************************************************************

function cdrspec_for_tile, cdr_row, cdr_spec, tile_row, cdr4tile


ntile = n_elements(tile_row)
cdr4tile = replicate(65535.0, ntile)   ; Initialize invalid in case some bands unmatched 

; Histograms of each row index vector, on same range, are both nonzero 
; only at row indices where both match.
a = min(tile_row, max=b)
ht = histogram(tile_row, min=a, max=b, reverse_indices=rt)
hc = histogram(cdr_row, min=a, max=b, reverse_indices=rc)
k = where(((ht ne 0) and (hc ne 0)), n_match)
if (n_match ne 0) then begin
	tile_match = rt[rt[k]]
	cdr_match = rc[rc[k]]
	for j=0,n_match-1 do cdr4tile[tile_match[j]] = cdr_spec[cdr_match[j]]
endif else begin
	return, -1
endelse

return,0
end
