;
;  This is a simple unit test to demonstrate that the expand_crism_cube
;  function performs as advertised
;
;

pro unit_expand_crism_cube

    ;
    ;  Make a window large enough to hold the largest crism frame
    ;   ( used for display purposes only )
    ;
    window, 0, xsize=640, ysize=480
    dirname = '../../../test_data/sample_edrs/'

    ;
    ;  Idenitify a list of EDR filenames to loop over
    ;
    filenames = [ 'EPF00002782_19_SC156S_EDR0.LBL', $
                  'ICL00002785_01_SP130S_EDR0.LBL']

    ;
    ;  Loop over the sample EDRs provided
    ;
    for iii=0, n_elements(filenames)-1 do begin
        filename = filenames[iii]

        ;
        ;  Read in the EDR and produce a strucure similar to what would
        ;  be returned if we extracted the image and rownum_table objects
        ;  ( we have to do this because the ascii table reader is horribly
        ;  slow. )
        ;
        ;  If the reader wasnt slow, the following line would suffice:
        ;edrstruct = readpds(dirname+filename)
        ;
        ;  Instead, we can read the image and the rownum table and combine
        ;  the resulting structures
        edrstruct_img  = readpds( dirname+filename, 'IMAGE')
        edrstruct_rows = readpds( dirname+filename, 'ROWNUM_TABLE')
        edrstruct = create_struct ( 'objects', 2,                 $
                                    'image', edrstruct_img.image, $
                                    'rownum_table', edrstruct_rows.rownum_table)
        ;
        ;  Expanding the result
        ;
        expanded_cube = expand_crism_cube ( edrstruct )
        imagecube = expanded_cube.image
        imgsize = size ( imagecube, /stru)
        a=make_array (imgsize.dimensions[0], imgsize.dimensions[2], /uint, value=0 )
        a[*,*] = imagecube [ *, 0, *]
        help, a
        tvscl, a
    endfor

end
