;******************************************************************************
;
; function crism_wavelength_shift, wc_coeff, bench_temp
;
; Calculate CRISM wavelength shift from optical bench temperature and WC 
; coefficients.
;
; INPUT:
;	wc_coeff     fltarr(3)     WC Coefficients  [ave shift, slope, ave temp]
;	bench_temp   float         Optical bench temperature (C)
;
; OUTPUT:
;	Parameters: None
;	Return value: 
;		(float)   Wavelength shift in nm (fail: 65535.0)
;
; KEYWORDS: None.
;
; NOTES:
;	Input bench_temp and return can be arrays.
;
; USES: nothing
;
; HISTORY:
;	2008 Nov 02 F. Morgan    First version
;	2009 Sep 16 F. Morgan    Change arguments; input = coefficients and temperature.
;	2009 Sep 28 F. Morgan    Bug fix - put [i] on delta_wv assignment; was returning 
;	                         only scalar value for last temp.
;
;******************************************************************************

function crism_wavelength_shift, wc_coeff, bench_temp

if (n_elements(wc_coeff) ne 3) then return,65535.0

ndw = n_elements(bench_temp)
if (ndw lt 1) then return,65535.0
delta_wv = fltarr(ndw)
for i=0L,ndw-1 do delta_wv[i] = wc_coeff[0] + wc_coeff[1] * (bench_temp[i] - wc_coeff[2])
if ((size(bench_temp))[0] eq 0) then delta_wv=delta_wv[0]
return,delta_wv
end
