;******************************************************************************
;
; function crism_waves2microns, waves
;
; Given CRISM wavelengths, convert to microns, WITHOUT CHANGING INVALID 
; WAVELENGTHS = 65535.
;
; INPUT:
;	waves		 flt[arr] or dbl[arr]	CRISM wavelengths (nm or microns)
;
; OUTPUT:
;	Parameters:  none
;	Return value:  Identical wavelength [array] but valid nm converted to microns
;
; KEYWORDS: none
;
; NOTES:
;
; USES: No external procedures.
;
; HISTORY:
;	2009 Mar 31 F. Morgan: First version written and tested. This routine is 
;	            intended to replace crism_nm2microns, so calling procedure 
;	            doesn't have to check wavelength units before call.
;
;******************************************************************************

function crism_waves2microns, waves

CRISM_NAN_LOW = 65535. * 0.999999    ; to allow numerical slop


; Identify valid wavelengths:
k = where((waves lt CRISM_NAN_LOW), ngood)

; Convert good wavelengths (if there were any) leaving bad wavelengths alone,
; but only do conversion if inputs are in microns:
wave_mic = waves
if (ngood gt 0) then begin
	if (median(waves[k]) gt 100.) then wave_mic[k] /= 1000.
endif

return, wave_mic
end
