;******************************************************************************
;
; function crm_bisect_idsrch, obsinfo, obsid
;
; Return index ob observation info struct where observation index 
; 'obsid' is located.
;
; INPUT:
;	obsinfo     structarr     Observation info... 
;	                           obsinfo.id = observation ID
; 	obsid       long          Requested observation ID
;
; OUTPUT: no parameters
;
; RETURN VALUE:
;	Index j such that obsinfo[j].id = obsid, or -1 if no 'obsid' in array.
;
; NOTES:
;	OBSINFO MUST BE SORTED IN INCREASING obsinfo.id ORDER
;
;	Use bisection after bracketing the target.
;
;	Used by autolist_tile_cdr4s, autolist_tile_vsadr.
;
; HISTORY:
;	2009 Sep 19   Separated from file autolist_tile_cdr4s.pro; originally 
;	              created 2008 Dec 31.
;
;******************************************************************************

function crm_bisect_idsrch, obsinfo, obsid

common CRM_BIS_IDSRCH_STATIC, ia, ib

nobs = n_elements(obsinfo)

; Bracket the requested obs ID:
if (n_elements(ia) eq 0) then begin
	ia = 0L
	ib = nobs-1
endif else begin
	while ((obsinfo[ia].id gt obsid) and (ia gt 0)) do ia = (2L*ia-ib) > 0
	while ((obsinfo[ib].id lt obsid) and (ib lt nobs-1)) do ib = (2L*ib-ia) < (nobs-1)
endelse
if (obsid lt obsinfo[ia].id) then return,-1
if (obsid gt obsinfo[ib].id) then return,-1

; Now obsinfo[ia].id <= obsid <= obsinfo[ib].id 

; Bisect:
while (ib-ia gt 1L) do begin
	m = (ia+ib)/2L
	if (obsinfo[m].id gt obsid) then ib=m else ia=m
endwhile
if (obsinfo[ia].id eq obsid) then begin
	return,ia
endif else if (obsinfo[ib].id eq obsid) then begin
	return,ib
endif else begin
	; Bracketed, but neither equal.. no such ID
	return, -1
endelse
end
