;******************************************************************************
;
; function date_from_missionday, date_dom1, dom
;
; Date yyyy_ddd from day of mission.
;
; INPUT:
;	date_dom1    string   Date yyyy_ddd on mission day 1.
;	dom          int      Day of mission, =1 at date_dom1, daily increment
;
; OUTPUT PARAMETERS: None
;
; RETURN VALUE:
;	String yyyy_ddd at day of mission 'dom'
;
; KEYWORDS: None.
;
; NOTES:
;
; USES:
;	cat_days_in_year
;
; HISTORY:
;	2009 Mar 25 F. Morgan: First version written. Tested 4/2.
;
;******************************************************************************

function date_from_missionday, date_dom1, dom

d1 = strtrim(date_dom1,2)
y1 = fix(strmid(d1,0,4))
day1 = fix(strmid(d1,5,3))

this_year = y1
this_day = day1 + dom - 1

dty = cat_days_in_year(this_year)
while (this_day gt dty) do begin
	this_day -= dty
	this_year++
	dty = cat_days_in_year(this_year)
endwhile
return, string(this_year,format='(I4.4)') + '_' + string(this_day,format='(I3.3)')
end
