function cat_pds_path, fnm

; Return path to the top of a PDS archive tree; returns '' if not found.
;
; INPUT:
;	fnm   string    Optional filename for a TRDR, MRDR, CDR, or EDR file, with full
;	                path, that will be searched for a pds-like tree root
;	                if a valid root not found from config file.
;
; OUTPUT PARAMETERS: none
;
; RETURN VALUE:
;	String = path to root of PDS tree; '' if fail


forward_function get_catcfg_param

psep = path_sep()

pdspath = get_catcfg_param('CRISM_PDS_PATH')
if (~file_test(pdspath)) then begin
	if (n_elements(fnm) eq 1) then begin
		; Try to get if from the input file name, for TRDR, MRDR, CDR or EDR
		pt = strpos(fnm[0],'trdr'+psep+'TRDR')
		if (pt lt 0) then begin
			pt = strpos(fnm[0],'mrdr'+psep+'MRDR')
		endif
		if (pt lt 0) then begin
			pt = strpos(fnm[0],'edr'+psep+'CDR')
		endif
		if (pt lt 0) then begin
			pt = strpos(fnm[0],'edr'+psep+'EDR')
		endif
		if (pt gt 0) then begin
			pdspath = strmid(fnm[0],0,pt)
		endif
	endif
endif

; Final check:
if (~file_test(pdspath)) then return,''

; Make sure ends with path separator:
pdspath = strtrim(pdspath,2)
if (strmid(pdspath, strlen(pdspath)-1, 1) ne psep) then pdspath += psep

return, pdspath
end
