;******************************************************************************
;
; function pdsfile_is_tile
;
; Given the filename of a PDS file, determine whether it is a CRISM map tile
; or not.
;
; INPUT:
;	fnm		string		File path+name (path not used if present)
;
; OUTPUT:
;	Parameters: none
;	Return value: 0, not tile; 1, is a tile
;
; KEYWORDS: none
;
; NOTES:
;	Returns 1 (true) iff the input file is a map tile. 
;
;	THE FILE IS ASSUMED TO EXIST AND TO BE A PDS FILE, or at least to have a name
;	descended from PDS convention (in which a tile file uniquely includes 'MRR').
;
; USES:
;	No external procedures.
;
; HISTORY:
;	2007 Aug 20 F. Morgan: First version written and tested.
;	2007 Nov 19 F. Morgan: documentation edit
;	2008 Apr 24 F. Morgan: added underscore to _MRR 
;	2008 Apr 24 F. Morgan: added file_basename() in case _MRR occurs in path
;
;******************************************************************************

function pdsfile_is_tile, fnm

if (strpos(strupcase(file_basename(fnm)),'_MRR') ge 0) then return,1
return,0
end
