;******************************************************************************
;
; function pick_latest_pds_version, pds_files
;
; Given a set of PDS filenames, return the one with the highest version
; number.
;
; INPUT:
;	pds_files   strarr     Array of filenames
;
; OUTPUT: no parameters
;
; RETURN VALUE:
;	Filename with maximum version number. '' if none have identifiable 
;	version numbers.
;
; NOTES:
;	PDS version number is taken as the last _d_ or d. before extension in a file
;	basename, where d represents one or more decimal digits.  Any string 
;	lacking such an element is ignored.
;	In either abcd_efg_1.img or abcd_efgh_1_extra.img  version=1 is OK.
;
; HISTORY:
;	2009 Jan 02   First version, F.Morgan
;	2009 Feb 09   FM: change is_digit() to cat_is_digit() to avoid 
;	              conflict with similarly named procedures
;	2009 Feb 22   FM: Use strings for version, not int, to accomodate a..z
;	2009 Feb 22   FM: Generalize to non-CDR files; was assuming single digit 
;	                  version in last segment of filename. True only for 
;	                  unappended CDR names. Caused failure in pds->cat conversion 
;	                  of segments 0A, 0B... of FRT because failed to find 
;	                  a segment interpreted as a version.
;	2009 Feb 22   FM: Use get_pds_version and then return max. All logic goes 
;	                  there now.
;
;******************************************************************************

function pick_latest_pds_version, pds_files

forward_function get_pds_version

if (n_elements(pds_files) eq 0) then return,''
vers = get_pds_version(pds_files, latest_vers)
k = where(vers eq latest_vers)
mvfile = pds_files[k[0]]
return, mvfile
end
