;******************************************************************************
;
; function get_algk_temperature
;
; CAT/ENVI function to get the AlgK thermal model surface temperature 
; corresponding to a CRISM image.
;
; INPUT:
;	fnm		CRISM image filename
;
; OUTPUT PARAMETERS:
;	temp	fltarr		Surface temperature from AlgK at CRISM image pixels
;
; RETURN VALUE:
;	Status
;		0    Success
;		non-zero: fail on input retrieval function
;		
; KEYWORDS: none
;
; EXAMPLE:
;
; NOTES:
;		
; USES:
;	No external procedures.
;
; HISTORY:
;	2008 Sep 09   F. Morgan: First version written.
;
;******************************************************************************

function get_algk_temperature, fnm, temp


stat = get_algk_inputs(fnm, lsubs, lst, lat, alb, thrm_inrt, slope_mag, slope_az, opac, elev) 
if (stat ne 0) then return, stat

temp = algk_surface_temp_image(lsubs, lat, lst, alb, thrm_inrt, slope_mag, slope_az, opac, elev)

return, stat
end
