function bin6r,  name,head = head , quiet = quiet, types_instruc,  verbose_bin6r=verbose_bin6r
; read binary files with 'standard' header
;_args
; name	!i. file name
; head !o. string of creation date and initial text
; verbose !k. if set, print out file arch
; quiet !k. not currently installed
;_desc this routine matched with  bin5w
;
; USAGE  array_read = bin5r (file_name, head=descriptive_text_in_file)
; ss=size(aa) ; see SIZE  @ R1-248
;  npts = n_elements(aa(*,0) ; if a 2-D file
; Returns a floating scalar of  operr  if there is an error opening file
;_hist  97apr27 Hugh Kieffer   98mar15 revise header handling
; 98may08 check byte architecture, swap if necessary
; 98jun24 add verbose keyword.  routine now defaults to silent running.
; 98jul02 TNT added ability to read in string data
; 99apr19 TNT added Hugh's variable length header by searching for C_END.
; 00Oct18 TNT changed nomenclature to bin6.
; 08Feb23 PCM Added types_instring argument, changed its default value
; 08Feb23 PCM                 also added 'x86_64  ' value to this string
; 08Feb23 PCM changed verbose to verbose_bin6r
; 08Feb29 MFM changed types_instring to types_instruc and modified
;             associated byte swapping logic.
;_end

;if not keyword_set(quiet) then verbose_bin6r=1 else verbose_bin6r = 0
;print,verbose_bin6r,'B',keyword_set(verbose_bin6r),quiet,'C',types_instring,'D','E',name
;verbose_bin6r = 1
if verbose_bin6r then print,name
openr,iod,name,error=operr,/get	; open the binary file
if operr ne 0 then begin
	print,'BIN6R: open ERROR # and file=',operr,name,strmessage(operr)
	aa=operr
	if keyword_set(iod) then free_lun,iod
	return,aa
  endif

rec=assoc(iod,bytarr(512))	;create records of 512K
i=0 & while strpos(string(rec[i]),'C_END') eq -1 do i=i+1 & i=i+1
headlen=512*i		; header length
bb=bytarr(headlen)	; create a dummy buffer to read to end of header
ndim=1L			; create a longword to read the #_dimensions
point_lun,iod,0		; reset the file pointer to beginning
readu,iod, bb		; read entire header as byte array
hh=string(bb)		; convert entire header to a string
reads,hh,ndim		; extract # dimensions from header

;determine if byte order is different
arch=!version.arch
if verbose_bin6r then print,'>',arch,'<cpu_arch'
farch=strmid(hh,headlen-10,5)
if verbose_bin6r then print,'>',farch,'<file_arch'

;x86_64 added PCM 2/23/2008
;types='sparc alpha x86 x86_64   ' ; all types handled, blank assumed to be sparc

; comment PCM 2/23/2008: on our 64bit windows machine (hamilton), the farch is 'x86  ',
;                                                 with two extra spaces
;                        so I changed the types string in order to match.
;                        a bit of a kludge... :(

;x86_64 added PCM 2/23/2008
;types='sparc alpha x86   x86_64   ' ; all types handled, blank assumed to be sparc
;types=types_instring ;PCM 2/23/2008 I put this string on outside, for portability

; Frank M, 2/29/2008: revised arcitecture family determination; use input struct 
;    types_instruc = { sparc_family: <string array with sparc-like !version.arch values>, $
;                      x86_family: <string array with x86-like !version.arch values> }

; Check architecture family for later decision about byte swapping.
; Local architecture:
if (max(strpos(types_instruc.sparc_family, arch)) ge 0) then begin
	here = 0
endif else if (max(strpos(types_instruc.x86_family, arch)) ge 0) then begin
	here = 1
endif else begin
	return, -1   ; Local architecture not found in types_instruc 
endelse
; File source architecture:
if (max(strpos(types_instruc.sparc_family, farch)) ge 0) then begin
	file = 0
endif else if (max(strpos(types_instruc.x86_family, farch)) ge 0) then begin
	file = 1
endif else begin
	return, -2  ; File source architecture not found in types_instruc 
endelse

; Above replaces the following code by PCM. Had types=types_instring, 
; types_instring was an input like 'sparc alpha x86   x86_64   '
; ============   Start Replaced Code Block Here  ===============
;sparc_char_pos=5 ;comment PCM 2/23/2008: if  strpos returns i>=0, then there is a match
;                 ;                       if  strpos returns i>5 then the match is not a sparc
;i=strpos(types,arch)
;if i gt sparc_char_pos then here=1 else here=0
;i=strpos(types,farch)
;if i gt sparc_char_pos then file=1 else file=0
;if verbose_bin6r then print,'here and file=',here,file
; ============   End Replaced Code Block Here  ===============

; return header through the HEAD keyword; trim off sizes and C_END
i=strpos(hh,'>>') 		; find end of date
head=strmid(hh,i+2,headlen-12-i); extract range that might contain text
head=strtrim(head,2)		; and trim trailing blanks

slen=strlen(string_all_before(hh,'{'))/12
if slen eq 0 then slen=ndim+3
ss=lonarr(slen)			; create the  size  array
reads,hh,ss			; extract  size  from header
if ss(ss(0)+1) eq 8 then tags=$
	str_sep(string_all_after(string_all_before(hh,'}'),'{'),string(9b)) $
	else tags=''
aa=make_xarray(ss,tags)		; create the array
;debugging comments PCM (2006-2007)
;print,'aa=',size(aa)
;print,'ss=',size(ss)
;print,'data(ss)=',ss
;print,'data(tags)=',tags
readu,iod, aa			; read header and data array

free_lun,iod                    ; close  and free up the logical unit
if here ne file then begin
 if verbose_bin6r then print,'swapping'
	aa=swap_endian(temporary(aa))
  endif

;debugging comments PCM (2006-2007)
;print,'data(aa)=',aa

return,aa
end
