; Procedure to programatically define the CAT menu within ENVI.
;  Avoids requiring user to edit or replace envi.men and 
;  display.men files after every ENVI reinstallation.
;
; Created: June 2006
;      By: Shannon Pelkey
;
; Note: The reason this runs at startup... see ENVI help menus/adding buttons...
;      ENVI looks for XXX_define_buttons in save_add/XXX.pro and runs that 
;      code to set up the menu.
;
; Modification history:
;  2007-09-18  FM --add version number to CAT menu item; 
;                   new variables cat_menu_label, and menu_ref to 
;                   set a commonly used ref_value keyword once
;  2007-11-26  FM --added menu item for bad bands list, but left commented
;                   out for now because of implementation trouble
;  2008-05-13  FM --added menu items for Crism Clean and for hyperspectral 
;                   summary parameters. 
;  2008-09-01  FM --added cat_startup call at end
;  2009-03-04  FM --added Oli's FITS reader to menu
;  2009-03-10  FS --added MRO CRISM Continuum Cube menu hitch under Spectral Analysis Utilities
;    	    	  --changed Spectral Stats to MRO CRISM Spectral Stats
;   	    	  --commented out DISORT MULTIDL and Thermal Model main CAT menu items
;   	    	  --changed CATNIP to Data Filtering
;   	    	  --reordered Data Filtering menu
;   	    	  --changed CRISM CLEAN to CIRRUS in multiple locations
;   	    	  --changed Remove Stripes to MRO CRISM Remove Stripes
;  2009-03-04  FM --Moved cat_startup run to top; made FITS reader devel version only
;  2010-02-25  FM --Added fix for old tile headers to menu
;  2011-11-14  FS --redirected mro_crism_continuum_cube CAT/ENVI call to mro_crism_continuum_cube_cat_envi <-- CAT-specific interface
;  2015-02-27  FM --Deprecated old summary parameter functions
;                 --Added hook to new summary parameters
;

pro cat_menu_define_buttons, buttonInfo


  ;*******************************************************************
  ; INVOKE CAT_STARTUP
  ;*******************************************************************
  ; This is maybe a bit of a kluge; but since this routine is 
  ; automatcally run by ENVI at startup it is a convenient place to 
  ; invoke cat_startup to take care of initiallization stuff for CAT.
  ; Need before menu setup -= use some params to configure menus.

  cat_startup


  ;*******************************************************************
  ; ADDITIONS TO THE ENVI MAIN MENU:
  ;*******************************************************************

  ; get CAT name and version for menu bar:
  cat_version, cat_name, catver
  cat_menu_label = strtrim(cat_name,2) + ' ' + strtrim(catver,2) + '   '
  menu_ref = cat_menu_label
  ENVI_DEFINE_MENU_BUTTON, buttonInfo, Value=cat_menu_label, $
    ref_value = 'File', /Sibling, position='before', /Menu

  ENVI_DEFINE_MENU_BUTTON, buttonInfo, Value='Exit  ', $
    ref_value = menu_ref, /Sibling, position='before',/Menu
  
  a=0
  ENVI_DEFINE_MENU_BUTTON, buttonInfo, Value='Reload CAT config file', $
    ref_value=menu_ref, position=a,event_pro='reload_catcfg_event',uvalue='not used'

  a=a+1
  ENVI_DEFINE_MENU_BUTTON, buttonInfo, Value='Open CRISM File', $
    ref_value=menu_ref, position=a,event_pro='read_crism_event',uvalue='open', $
    separator=1

  a=a+1
  ENVI_DEFINE_MENU_BUTTON, buttonInfo, Value='Convert Format: PDS to CAT', $
    ref_value=menu_ref, position=a,event_pro='convert_pds2cat_event',uvalue='not used'

;  a=a+1
;  ENVI_DEFINE_MENU_BUTTON, buttonInfo, Value='Apply CRISM Bad Bands List', $
;    ref_value=menu_ref, position=a,event_pro='apply_bbl_event',uvalue='not used'

  a=a+1
  ENVI_DEFINE_MENU_BUTTON, buttonInfo, Value='Radiance to I/F', $ 
    ref_value=menu_ref, position=a,event_pro='r2if_event', $
    uvalue='r2if',separator=1

  a=a+1
  ENVI_DEFINE_MENU_BUTTON, buttonInfo, Value='ATP Corrections', $     
    ref_value=menu_ref, position=a,event_pro='atpcorr_event', $
    uvalue='atpcorr'

;  a=a+1
;  ENVI_DEFINE_MENU_BUTTON, buttonInfo, Value='DISORT MULTIDL', $   
;    ref_value=menu_ref, position=a, $
;    event_pro='cat_not_yet',uvalue='not used',separator=1

  a=a+1
  ENVI_DEFINE_MENU_BUTTON, buttonInfo, Value='EPF Utilities', $   
    ref_value=menu_ref, position=a, /menu,separator=1
    ENVI_DEFINE_MENU_BUTTON, buttonInfo, Value='Project Segments', $     
      ref_value='EPF Utilities', position=0, $
      event_pro='epf_event',uvalue='view'
    ENVI_DEFINE_MENU_BUTTON, buttonInfo, Value='Project and Plot', $     
      ref_value='EPF Utilities', position=1,/menu
      ENVI_DEFINE_MENU_BUTTON, buttonInfo, Value='Overlap Area', $     
        ref_value='Project and Plot', position=0, $
        event_pro='epf_event',uvalue='plot_overlap'   
      ENVI_DEFINE_MENU_BUTTON, buttonInfo, Value='User Defined Subset', $     
        ref_value='Project and Plot', position=1, $
        event_pro='epf_event',uvalue='plot_subset'

  a=a+1
  ENVI_DEFINE_MENU_BUTTON, buttonInfo, Value='Spectral Analysis Utilities', $     
    ref_value=menu_ref, position=a,/menu,separator=1
    sabutpos = 0

    ENVI_DEFINE_MENU_BUTTON, buttonInfo, Value='2014 Summary Products', $     
      ref_value='Spectral Analysis Utilities', position=sabutpos,uvalue='not used', /menu
        ENVI_DEFINE_MENU_BUTTON, buttonInfo, value = 'VNIR Data', uvalue = 'VNIR',$
          ref_value = '2014 Summary Products',position=0, event_pro = 'mro_crism_summary_params_2014_event'
        ENVI_DEFINE_MENU_BUTTON, buttonInfo, value = 'IR Data', uvalue = 'IR',$
          ref_value = '2014 Summary Products',position=1, event_pro = 'mro_crism_summary_params_2014_event'
        ENVI_DEFINE_MENU_BUTTON, buttonInfo, value = 'Joined Data', uvalue = 'Joined',$
          ref_value = '2014 Summary Products',position=2, event_pro = 'mro_crism_summary_params_2014_event'

    sabutpos++
    ENVI_DEFINE_MENU_BUTTON, buttonInfo, Value='Old Summary Parameters - DEPRECATED', $     
      ref_value='Spectral Analysis Utilities', position=sabutpos,uvalue='not used',/menu

      ENVI_DEFINE_MENU_BUTTON, buttonInfo, Value='Spectral Summary Products', $     
        ref_value='Old Summary Parameters - DEPRECATED', position=sabutpos,uvalue='not used',/menu
        ENVI_DEFINE_MENU_BUTTON, buttonInfo, value = 'VNIR Data', uvalue = 'VNIR',$
          ref_value = 'Spectral Summary Products',position=0, event_pro = 'mro_crism_summary_params_event'
        ENVI_DEFINE_MENU_BUTTON, buttonInfo, value = 'IR Data', uvalue = 'IR',$
          ref_value = 'Spectral Summary Products',position=1, event_pro = 'mro_crism_summary_params_event'
        ENVI_DEFINE_MENU_BUTTON, buttonInfo, value = 'Joined Data', uvalue = 'Joined',$
          ref_value = 'Spectral Summary Products',position=2, event_pro = 'mro_crism_summary_params_event'
      sabutpos++
      ENVI_DEFINE_MENU_BUTTON, buttonInfo, Value='Hyperspectral Summary Products', $     
        ref_value='Old Summary Parameters - DEPRECATED', position=sabutpos,uvalue='not used',/menu
        ENVI_DEFINE_MENU_BUTTON, buttonInfo, value = 'IR Data', uvalue = 'IR',$
          ref_value = 'Hyperspectral Summary Products',position=0, $
          event_pro = 'mro_crism_summary_params_hyper_event'
      sabutpos++
    ENVI_DEFINE_MENU_BUTTON, buttonInfo, Value='Run MGM on IR Data', $     
      ref_value='Spectral Analysis Utilities', position=sabutpos, $
;      event_pro='cat_not_yet',uvalue='not used',separator=1
      event_pro='mgm_event',uvalue='not used',separator=1
    sabutpos++
    ENVI_DEFINE_MENU_BUTTON, buttonInfo, Value='MRO CRISM Continuum Cube', $     
      ref_value='Spectral Analysis Utilities',position=sabutpos,event_pro='mro_crism_continuum_cube_cat_envi',$
      uvalue='not used',separator=1
    sabutpos++
    ENVI_DEFINE_MENU_BUTTON, buttonInfo, Value='MRO CRISM Spectral Stats', $     
      ref_value='Spectral Analysis Utilities',position=sabutpos,event_pro='mro_crism_spectral_stats_envi',$
      uvalue='not used',separator=0 

  a=a+1
  ENVI_DEFINE_MENU_BUTTON, buttonInfo, Value='Map Utilities', $     
    ref_value=menu_ref, position=a,/menu, separator=1
    ENVI_DEFINE_MENU_BUTTON, buttonInfo, Value='Project Single Cube Data', $     
      ref_value='Map Utilities',position=0,event_pro='projection_event',$
      uvalue='not used'
    ENVI_DEFINE_MENU_BUTTON, buttonInfo, value='LATLONINATOR', uvalue='LATLONINATOR',$
       ref_value ='Map Utilities',position=1,event_pro='latloninator',separator=1
    ENVI_DEFINE_MENU_BUTTON, buttonInfo, value='Fix Old Tile Map Info', uvalue = 'not used',$
       ref_value ='Map Utilities',position=2,event_pro='tilemap_fix_event',separator=1

  a=a+1
  ENVI_DEFINE_MENU_BUTTON, buttonInfo, Value='Data Filtering', $
    ref_value=menu_ref, position=a,/menu, separator=1
    ENVI_DEFINE_MENU_BUTTON, buttonInfo, Value='CIRRUS', $
      ref_value='Data Filtering',position=0, /menu
      ENVI_DEFINE_MENU_BUTTON, buttonInfo, Value='Clean Spectral Cube', $
        ref_value='CIRRUS',position=0,event_pro='mro_crism_clean_envi',$
        uvalue='not used' ;ezn 04-03-08
      ENVI_DEFINE_MENU_BUTTON, buttonInfo, Value='CIRRUS Help', ref_value='CIRRUS', $
        position=1, event_pro='crism_clean_help_event', uvalue='not used' 
    ENVI_DEFINE_MENU_BUTTON, buttonInfo, Value='MRO CRISM Remove Stripes', $     
      ref_value='Data Filtering',position=1,event_pro='mro_crism_remove_stripes_envi',$
      uvalue='not used'
    ENVI_DEFINE_MENU_BUTTON, buttonInfo, Value='Flatten Summary Products', $     
      ref_value='Data Filtering',position=2,event_pro='mro_crism_summary_flatten_envi',$
      uvalue='not used'

  a=a+1
  ENVI_DEFINE_MENU_BUTTON, buttonInfo, Value='Miscellaneous Utilities', $
    ref_value=menu_ref, position=a,/menu, separator=1
    ENVI_DEFINE_MENU_BUTTON, buttonInfo, Value='IR Spectral Shift', $
      ref_value='Miscellaneous Utilities',position=0,event_pro='crism_waveshift_event',$
      uvalue='not used' ;mfm Mar-12-2009

  a=a+1
  ENVI_DEFINE_MENU_BUTTON, buttonInfo, Value='Apply CRISM Bad Bands', $     
    ref_value=menu_ref, position=a,event_pro='apply_bbl_event', $
    uvalue='not used', separator=1    ; mfm March 2009


;  a=a+1
;  ENVI_DEFINE_MENU_BUTTON, buttonInfo, Value='Thermal Model', $
;    ref_value=menu_ref, position=a,/menu, separator=1
;    ENVI_DEFINE_MENU_BUTTON, buttonInfo, Value='AlgK Surface Temperature', $     
;      ref_value='Thermal Model',position=0,event_pro='algk_temperature_event',$
;      uvalue='not used'

;  a=a+1
;  ENVI_DEFINE_MENU_BUTTON, buttonInfo, Value='CAT TESTING', $   
;    ref_value=menu_ref, position=a, /menu,separator=1
;    ENVI_DEFINE_MENU_BUTTON, buttonInfo, Value='Summary Products Testing BE', $     
;      ref_value='CAT TESTING', position=1,uvalue='not used',/menu
;      ENVI_DEFINE_MENU_BUTTON, buttonInfo, value = 'VNIR Summary Products', uvalue = 'VNIR Summary Parameters',$
;        ref_value = 'Summary Products Testing BE',position=0, event_pro = 'mro_crism_summary_params_envi_be'
;      ENVI_DEFINE_MENU_BUTTON, buttonInfo, value = 'IR Summary Products', uvalue = 'IR Summary Parameters',$
;        ref_value = 'Summary Products Testing BE',position=1, event_pro = 'mro_crism_summary_params_envi_be'


  ;*******************************************************************
  ; ADDITIONS TO THE ENVI HELP MENU:
  ;*******************************************************************

  ENVI_DEFINE_MENU_BUTTON, buttonInfo, Value='CAT User Guide', $     
    ref_value='Help', position=1,event_pro='cat_help_event',$
    uvalue='cathelp',separator=1

  ENVI_DEFINE_MENU_BUTTON, buttonInfo, Value='CRISM SIS', $     
    ref_value='CAT User Guide', position=1,/menu
    ENVI_DEFINE_MENU_BUTTON, buttonInfo, Value='Data Products (DPSIS)', $     
      ref_value='CRISM SIS', position=0,event_pro='cat_help_event',$
      uvalue='dpsis'
    ENVI_DEFINE_MENU_BUTTON, buttonInfo, Value='Archive Volume (AVSIS)', $     
      ref_value='CRISM SIS', position=1,event_pro='cat_help_event',$
      uvalue='avsis'

  
  ;*******************************************************************
  ; ADDITIONS TO THE ENVI FILE MENU:
  ;*******************************************************************
  if (strtrim(get_catcfg_param('CAT_DEV_VERSION'),2) eq '1') then begin
    ENVI_DEFINE_MENU_BUTTON, buttonInfo, Value='FITS', $
      ref_value='Open External File', position='last',event_pro='envi_open_fits_gui',$
      uvalue='readfits',separator=1
  endif

  ;*******************************************************************
  ; ADDITIONS TO THE ENVI DISPLAY MENU:
  ;*******************************************************************

  ENVI_DEFINE_MENU_BUTTON, buttonInfo, /DISPLAY, Value='**CRISM**CDR Z Profile...', $  
    ref_value='Z Profile (Spectrum)...',/SIBLING, position='after', $
    event_pro='crism_zprofile_event',uvalue='not used'
  ENVI_DEFINE_MENU_BUTTON, buttonInfo, /DISPLAY, Value='CRISM Active Z-Profile...', $  
    ref_value='Z Profile (Spectrum)...',/SIBLING, position='after', $
    event_pro='crism_active_zprofile_event',uvalue='not used'
  ENVI_DEFINE_MENU_BUTTON, buttonInfo, /DISPLAY, Value='CAT Z-profile Scaling...', $  
    ref_value='CRISM Active Z-Profile...',/SIBLING, position='after', $
    event_pro='zprofile_axis_event',uvalue='not used'

end



